# Copyright 2021 Dominik George <nik@naturalnet.de>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os

import toml

DEFAULT_CONFIG_FILE = "/etc/nss_pam_oidc.toml"
DEFAULT_CONFIG = {
    "pam": {},
    "nss": {},
}


def get_config(section: str, **kwargs):
    """Get configuration for a section, layered from defaults, config file, and args."""
    config = {}

    # First, copy default configuration
    for name, conf in DEFAULT_CONFIG.items():
        config[name] = conf.copy()

    # Second, load configuration from file
    config_file = kwargs.pop("config", DEFAULT_CONFIG_FILE)
    if os.path.exists(config_file):
        config_toml = toml.load(config_file)
        for name, conf in config.items():
            conf.update(config_toml.get(name, {}))

    # Lastly, override with passed arguments
    config[section].update(kwargs)

    return config
